pylib
--
Library of Python tools. This is the mainly used interface for post-processing.

idllib
--
Library of IDL tools

matlablib
--
Library of Matlab tools.

eigensolver
--
Eigenvalue solver for ITG test case

pdb2idl
--
Library for reading PDB files into IDL

